@@ -280,8 +280,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                 mime = self.get_content_type()
                 poweredby = self.getheader('X-Powered-By', u'')
                 server = self.getheader('Server', u'')
-                if ((mime in ('application/octet-stream', 'text/plain') and
-                  (poweredby.startswith('Zope') or server.startswith('Zope')))
+                if (poweredby.startswith('Zope') or server.startswith('Zope')
                  or ('ASP.NET' in poweredby and 'Microsoft-IIS' in server)):
                     # Zope or IIS server could not get Content-Type with HEAD
                     # see http://intermapper.com.dev4.silvertech.net/bogus.aspx
@@ -468,7 +467,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         """
         data = self.get_cache_data()
         data["warnings"] = [
-            x for x in self.warnings if x[0] != "http-moved-permanent"]
+            x for x in self.warnings if x[0] != WARN_HTTP_MOVED_PERMANENT]
         data["info"] = self.info
         return data
 
